pitchtools.alphabetic_accidental_abbreviation_to_symbolic_accidental_string
===========================================================================

.. autofunction:: abjad.tools.pitchtools.alphabetic_accidental_abbreviation_to_symbolic_accidental_string.alphabetic_accidental_abbreviation_to_symbolic_accidental_string
